@@ -12,7 +12,7 @@ use Encode qw(decode);
 
 use vars qw[ $VERSION ];
 
-$VERSION = '0.29';
+$VERSION = '0.30';
 
 BEGIN {
   Finance::Bank::Postbank_de->mk_accessors(qw( agent login password urls ));
@@ -97,7 +97,7 @@ sub get_login_page {
   $self->agent(WWW::Mechanize->new( autocheck => 1, keep_alive => 1 ));
 
   my $agent = $self->agent();
-  $agent->add_header("If-SSL-Cert-Subject" => qr{\Q/1.3.6.1.4.1.311.60.2.1.3=DE/1.3.6.1.4.1.311.60.2.1.1=Bonn/businessCategory=Private Organization/serialNumber=HRB6793/C=DE/postalCode=53113/ST=NRW/L=Bonn/street=Friedrich Ebert Allee 114 126/O=Deutsche Postbank AG/OU=Systems AG/CN=banking.postbank.de}); 
+  $agent->add_header("If-SSL-Cert-Subject" => qr{\Q/1.3.6.1.4.1.311.60.2.1.3=DE/1.3.6.1.4.1.311.60.2.1.1=Bonn/businessCategory=Private Organization/serialNumber=HRB6793/C=DE/postalCode=53113/ST=NRW/L=Bonn/street=Friedrich Ebert Allee 114 126/O=Deutsche Postbank AG/OU=PB Systems AG/CN=banking.postbank.de}); 
 
   $agent->get(LOGIN);
   $self->log_httpresult();
